@@ -15,6 +15,7 @@ from PyFin.Math.Accumulators.IAccumulators import Acos
 from PyFin.Math.Accumulators.IAccumulators import Acosh
 from PyFin.Math.Accumulators.IAccumulators import Asin
 from PyFin.Math.Accumulators.IAccumulators import Asinh
+from PyFin.Math.Accumulators.IAccumulators import NormInv
 from PyFin.Math.Accumulators.IAccumulators import Latest
 from PyFin.Math.Accumulators.IAccumulators import Identity
 from PyFin.Math.Accumulators.IAccumulators import IIF
@@ -78,6 +79,7 @@ __all__ = ["Exp",
            "Acosh",
            "Asin",
            "Asinh",
+           "NormInv",
            "Latest",
            "Sign",
            "Diff",
