@@ -54,10 +54,15 @@ from PyFin.api.Analysis import ACOS
 from PyFin.api.Analysis import ACOSH
 from PyFin.api.Analysis import ASIN
 from PyFin.api.Analysis import ASINH
+from PyFin.api.Analysis import NORMINV
 from PyFin.api.Analysis import SHIFT
 from PyFin.api.Analysis import IIF
 
 from PyFin.api.Analysis import CSRank
+from PyFin.api.Analysis import CSTopN
+from PyFin.api.Analysis import CSBottomN
+from PyFin.api.Analysis import CSTopNQuantile
+from PyFin.api.Analysis import CSBottomNQuantile
 from PyFin.api.Analysis import CSMean
 from PyFin.api.Analysis import CSMeanAdjusted
 from PyFin.api.Analysis import CSQuantiles
@@ -115,9 +120,14 @@ __all__ = ["datesList",
            "ACOSH",
            "ASIN",
            "ASINH",
+           "NORMINV",
            "SHIFT",
            "IIF",
            "CSRank",
+           "CSTopN",
+           "CSBottomN",
+           "CSTopNQuantile",
+           "CSBottomNQuantile",
            "CSMean",
            "CSMeanAdjusted",
            "CSQuantiles",
